#!/bin/sh
#PR source: https://github.com/ubuntu/gnome-shell-extension-appindicator/pull/548
_extension_name=appindicatorsupportrgcjonas.gmail.com.v59.shell-extension
echo '[1/3] Download extension...'
cat > "./check.sha256" <<'EOF'
c76f0a5e0a1b835be046d0e437032a5c4a68b00947be0aa33c093c05b184e3c5  appindicatorsupportrgcjonas.gmail.com.v59.shell-extension.zip
EOF
curl -O https://extensions.gnome.org/extension-data/appindicatorsupportrgcjonas.gmail.com.v59.shell-extension.zip
sha256sum -c check.sha256 || exit
rm ./check.sha256
cat > github-pr548-v59.patch <<'EOF'
--- ./indicatorStatusIcon.js	2024-04-30 03:12:06.000000000 +0800
+++ "./appindicatorsupportrgcjonas.gmail.com.v59.shell-extension/indicatorStatusIcon.js"	2025-01-07 14:32:02.866361244 +0800
@@ -403,18 +403,31 @@ class IndicatorStatusIcon extends BaseSt
         }

         if (event.get_button() === Clutter.BUTTON_SECONDARY) {
-            this.menu.toggle();
+            if (this.menu.numMenuItems) {
+                this.menu.toggle();
+            } else {
+                // update menu if there's no entries
+                this._updateMenu();
+                // wait for menu update
+                this._waitForDoubleClick().catch(logError);
+            }
             return Clutter.EVENT_PROPAGATE;
         }

         const doubleClickHandled = this._maybeHandleDoubleClick(event);
         if (doubleClickHandled === Clutter.EVENT_PROPAGATE &&
-            event.get_button() === Clutter.BUTTON_PRIMARY &&
-            this.menu.numMenuItems) {
-            if (this._indicator.supportsActivation !== false)
+            event.get_button() === Clutter.BUTTON_PRIMARY) {
+            if (this.menu.numMenuItems) {
+                if (this._indicator.supportsActivation !== false)
+                    this._waitForDoubleClick().catch(logError);
+                else
+                    this.menu.toggle();
+            } else {
+                // update menu if there's no entries
+                this._updateMenu();
+                // wait for double click or menu update
                 this._waitForDoubleClick().catch(logError);
-            else
-                this.menu.toggle();
+        }
         }

         return Clutter.EVENT_PROPAGATE;
EOF
unzip "$_extension_name".zip -d patchdir
cd patchdir || exit
echo '[2/3] patch extension...'
patch -p0 <../github-pr548-v59.patch
zip -r ../"$_extension_name"-patched.zip ./*
cd ..
rm -rf ./patchdir/
rm ./github-pr548-v59.patch
echo '[3/3] install extension...'
gnome-extensions install "$_extension_name"-patched.zip
echo done!
